@@ -3,13 +3,7 @@ import numpy as np
 import tensorflow as tf  # type: ignore
 from numpy.typing import NDArray
 from code_loader.helpers.detection.utils import xywh_to_xyxy_format, jaccard
-from enum import Enum
-
-
-class YoloDecodingType(Enum):
-    YOLOV7 = 1
-    YOLOX = 2
-
+from code_loader.helpers.detection.yolo.enums import YoloDecodingType
 
 DEFAULT_FEATURE_MAPS = ((80, 80), (40, 40), (20, 20))
 DEFAULT_BOX_SIZES = (((10, 13), (16, 30), (33, 23)),
